/* ######################################################################### */
/* ##                                                                     ## */
/* ##  D B T U T O O L S / D B T U F F 2 C O D E . C                      ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Job .......: Program for interpreting the hex representation of    ## */
/* ##               DB2 internal error codes.                             ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Copyright (C) 2002  Daniel Scheibli                                ## */
/* ##                                                                     ## */
/* ##  This program is free software; you can redistribute it and/or      ## */
/* ##  modify it under the terms of the GNU General Public License        ## */
/* ##  as published by the Free Software Foundation; either version 2     ## */
/* ##  of the License, or (at your option) any later version.             ## */
/* ##                                                                     ## */
/* ##  This program is distributed in the hope that it will be useful,    ## */
/* ##  but WITHOUT ANY WARRANTY; without even the implied warranty of     ## */
/* ##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the      ## */
/* ##  GNU General Public License for more details.                       ## */
/* ##                                                                     ## */
/* ##  You should have received a copy of the GNU General Public License  ## */
/* ##  along with this program; if not, write to the Free Software        ## */
/* ##  Foundation, Inc., 59 Temple Place - Suite 330, Boston,             ## */
/* ##  MA  02111-1307, USA.                                               ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Author ....: Daniel Scheibli <daniel.scheibli@edelbyte.org>        ## */
/* ##  Date ......: 2002-04-25                                            ## */
/* ##  Changes ...: ----- dbtuff2code.c V00.99/R002 --------------------- ## */
/* ##               2002-05-12 - Shift to central headerfile.             ## */
/* ##               2002-05-07 - Change from printf() to fprintf().       ## */
/* ##               ----- dbtuff2code.c V00.99/R001 --------------------- ## */
/* ##               <none>                                                ## */
/* ##                                                                     ## */
/* ######################################################################### */



/* ##### Presettings */
/* ------------------------------------------------------------------------- */
#include "libdbtubase.h"
/* ------------------------------------------------------------------------- */





/* ######################################################################### */
/* ##                                                                     ## */
/* ##   < M A I N >                                                       ## */
/* ##                                                                     ## */
/* ######################################################################### */
int main( int argc, char *argv[] )
{
 /* ##### Presettings */
 /* ------------------------------------------------------------------------ */
 char *pcErrorToken1;
 char *pcErrorToken2;
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -- */ 
 int   iFfffToken = 0;
 char  acTempString[4+1];
 long  lErrorCode;
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -- */
 int   I;
 /* ------------------------------------------------------------------------ */



 /* ##### Check the given arguments */
 /* ------------------------------------------------------------------------ */
 if( argc != 3 )
 {
  fprintf(STDERR, "%s",                                                                NEWLINE);
  fprintf(STDERR, "===> ERROR: A minimum of two arguments was expected.%s",            NEWLINE);
  fprintf(STDERR, "     [%s (%i)]%s", __FILE__, __LINE__,                              NEWLINE);
  fprintf(STDERR, "%s",                                                                NEWLINE);
  fprintf(STDERR, "Usage .......: >>--- dbtuff2code ---- STRING1 --- STRING2 ---><%s", NEWLINE);
  fprintf(STDERR, "%s",                                                                NEWLINE);
  fprintf(STDERR, "Sample ......: dbtuff2code ffff e60a%s",                            NEWLINE);  
  fprintf(STDERR, "%s",                                                                NEWLINE);
  fprintf(STDERR, "Arguments ...: STRING1   The first 4 hexdigit string found in  %s", NEWLINE);  
  fprintf(STDERR, "                         the db2diag.log%s",                        NEWLINE);
  fprintf(STDERR, "Arguments ...: STRING2   The second 4 hexdigit string found in %s", NEWLINE);  
  fprintf(STDERR, "                         the db2diag.log%s",                        NEWLINE);
  fprintf(STDERR, "%s", NEWLINE);
  return(1);
 }
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -- */
 pcErrorToken1 = argv[1];
 pcErrorToken2 = argv[2]; 
 /* ------------------------------------------------------------------------ */ 



 /* ##### Check the given Error Code tokens */
 /* ------------------------------------------------------------------------ */
 if( (strlen(pcErrorToken1) != 4) || (strlen(pcErrorToken2) != 4) )
 {
  fprintf(STDERR, "%s",                                                             NEWLINE);
  fprintf(STDERR, "===> ERROR: Unexpected format of the given hexdigit strings.%s", NEWLINE);
  fprintf(STDERR, "     [%s (%i)]%s", __FILE__, __LINE__,                           NEWLINE);
  fprintf(STDERR, "%s",                                                             NEWLINE);
  return(1);
 }
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -- */
 if( STRICMP(pcErrorToken1, "FFFF") == 0 )
 { iFfffToken += 1; }
 if( STRICMP(pcErrorToken2, "FFFF") == 0 )
 { iFfffToken += 2; }
 if( iFfffToken == 0 )
 {
  fprintf(STDERR, "%s",                                                             NEWLINE);
  fprintf(STDERR, "===> ERROR: Unexpected format of the given hexdigit strings.%s", NEWLINE);
  fprintf(STDERR, "     [%s (%i)]%s", __FILE__, __LINE__,                           NEWLINE);
  fprintf(STDERR, "%s",                                                             NEWLINE);
  return(1);
 }
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -- */
 for( I = 0; I < strlen(pcErrorToken1); I++ )
 {
  if( (!ISHEXDIGIT(pcErrorToken1[I])) || (!ISHEXDIGIT(pcErrorToken2[I])) )
  {
   fprintf(STDERR, "%s",                                                             NEWLINE);
   fprintf(STDERR, "===> ERROR: Unexpected format of the given hexdigit strings.%s", NEWLINE);
   fprintf(STDERR, "     [%s (%i)]%s", __FILE__, __LINE__,                           NEWLINE);
   fprintf(STDERR, "%s",                                                             NEWLINE);
   return(1);
  } 
 }
 /* ------------------------------------------------------------------------ */



 /* ##### If we have "ffff ffff", we do not need to convert that */
 /* ------------------------------------------------------------------------ */
 if( iFfffToken == 3 )
 {
  fprintf(STDOUT, "%s",                                                                        NEWLINE);
  fprintf(STDOUT, "This special hexdigit string combination stands for an undefined error.%s", NEWLINE);
  fprintf(STDOUT, "%s",                                                                        NEWLINE);
  return(0);
 }
 /* ------------------------------------------------------------------------ */



 /* ##### Do conversion based on byte order */
 /* ------------------------------------------------------------------------ */
 /* ##### How to convert which byte order can be found within the                */
 /* ##### DB2 Documentation -> Troubleshooting Guide -> Interpreting db2diag.log */
 if( iFfffToken == 1 )
 { sprintf(acTempString, "%c%c%c%c", pcErrorToken2[0], pcErrorToken2[1], pcErrorToken2[2], pcErrorToken2[3]); }
 if( iFfffToken == 2 )
 { sprintf(acTempString, "%c%c%c%c", pcErrorToken1[2], pcErrorToken1[3], pcErrorToken1[0], pcErrorToken1[1]); }
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -- */ 
 acTempString[0] = toupper(acTempString[0]);
 acTempString[1] = toupper(acTempString[1]);
 acTempString[2] = toupper(acTempString[2]);
 acTempString[3] = toupper(acTempString[3]);   
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -- */  
 lErrorCode  = STRTOL(acTempString, (char **)NULL, 16);
 lErrorCode -= STRTOL("FFFF",       (char **)NULL, 16) + 1;
 /* ------------------------------------------------------------------------ */ 



 /* ##### Print the conversion result */
 /* ------------------------------------------------------------------------ */
 /* ##### TODO: The next step would be to check wether it is a.) or b.) */
 /* #####       and display the appendant part of the documentation.    */
 fprintf(STDOUT, "%s",                                                                                                            NEWLINE);
 fprintf(STDOUT, "The hexdigit string combination stands for %s",                                                                 NEWLINE);
 fprintf(STDOUT, "a.) SQL Message 'SQL%04i%c'          (see Message Reference)%s", abs(lErrorCode), (lErrorCode < 0) ? 'N' : 'W', NEWLINE); 
 fprintf(STDOUT, "b.) DB2 Internal Return Code '%s' (see Troubleshooting Guide)%s", acTempString,                                 NEWLINE);  
 fprintf(STDOUT, "%s",                                                                                                            NEWLINE); 
 /* ------------------------------------------------------------------------ */


 
 /* ##### End the program */
 /* ------------------------------------------------------------------------ */ 
 return(0);
 /* ------------------------------------------------------------------------ */ 
}




