#!/usr/bin/ksh
###############################################################################
##                                                                           ##
##  D B T U T O O L S / D B T U X C O N N E C T . S H                        ##
##                                                                           ##
## ------------------------------------------------------------------------- ##
##                                                                           ##
##  Job .......: Script to establish an exclusive connection (forcing        ##
##               existing connections to the database).                      ##
##                                                                           ##
## ------------------------------------------------------------------------- ##
##                                                                           ##
##  Copyright (C) 2002  Daniel Scheibli                                      ##
##                                                                           ##
##  This program is free software; you can redistribute it and/or modify it  ##
##  under the terms of the GNU General Public License as published by the    ##
##  Free Software Foundation; either version 2 of the License, or (at your   ##
##  option) any later version.                                               ##
##                                                                           ##
##  This program is distributed in the hope that it will be useful, but      ##
##  WITHOUT ANY WARRANTY; without even the implied warranty of               ##
##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            ##
##  GNU General Public License for more details.                             ##
##                                                                           ##
##  You should have received a copy of the GNU General Public License along  ##
##  with this program; if not, write to the Free Software Foundation, Inc.,  ##
##  59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.                 ##
##                                                                           ##
## ------------------------------------------------------------------------- ##
##                                                                           ##
##  Remark ....: <none>                                                      ##
##                                                                           ##
## ------------------------------------------------------------------------- ##
##                                                                           ##
##  Author ....: Daniel Scheibli <daniel.scheibli@edelbyte.org>              ##
##  Date ......: 2002-05-04                                                  ##
##  Changes ...: ----- dbtuxconnect.sh V00.99/R020 ------------------------- ##
##               <none>                                                      ##
##               ----- dbtuxconnect.sh V00.99/R011 ------------------------- ##
##               <none>                                                      ##
##               ----- dbtuxconnect.sh V00.99/R010 ------------------------- ##
##               2002-08-04 - Changed shell to Korn Shell (because it is an  ##
##                            requirement of IBM DB2 UDB, so we be can sure  ## 
##                            that it has been installed).                   ## 
##               2002-07-25 - Modified the lookup of the Application Handles ##
##                            (to be killed) - now Application Names with    ##
##                            blank in between will work too.                ##
##               2002-07-22 - The Fini() function will be released at the    ##
##                            end of the program too.                        ##
##               ----- dbtuxconnect.sh V00.99/R003 ------------------------- ##
##               <none>                                                      ##
##               ----- dbtuxconnect.sh V00.99/R002 ------------------------- ##
##               <none>                                                      ##
##               ----- dbtuxconnect.sh V00.99/R001 ------------------------- ##
##               <none>                                                      ##
##                                                                           ##
###############################################################################



##### Presettings
#------------------------------------------------------------------------------
echo; echo "DBTUXCONNECT.SH V00.99/R010"; echo
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - --
XX1FuncFini() {
 unset XX1ARGS XX1ARG1
 unset XX1DB
 unset XX1DUMMY 
 unset XX1STMT
}
#------------------------------------------------------------------------------



##### Process the given arguments
#------------------------------------------------------------------------------
XX1ARGS=$#; XX1ARG1=$1
while (($#>0))
do
 shift
done
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - --
if [ "$XX1ARGS" != "1" ]; then
 echo "===> ERROR: A minimum of one argument was expected."
 echo
 echo "Usage .......: >>--- . dbtuxconnect.sh --- ALIAS ---><"
 echo 
 echo "Sample ......: . dbtuxconnect.sh sample"
 echo
 echo "Arguments ...: ALIAS   The alias of the database the"
 echo "                       exclusive connection should be"
 echo "                       established for."
 echo
 XX1FuncFini; unset XX1FuncFini; return 1
fi
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - --
XX1DB=$(echo $XX1ARG1 | tr "[a-z]" "[A-Z]")
#------------------------------------------------------------------------------



##### Process the given arguments
#------------------------------------------------------------------------------
echo "Try to establish an exclusive connection to database '"$XX1DB"'"
echo "<Press ENTER to start>"
read XX1DUMMY
#------------------------------------------------------------------------------



##### Loop until connection is established
#------------------------------------------------------------------------------
while [ "1" != "2" ];
do
 ##### Try to connect to the database
 XX1STMT="CONNECT TO "$XX1DB" IN EXCLUSIVE MODE"
 echo $XX1STMT; db2 $XX1STMT
 case $? in
  0) ##### If connection was successfully established,...
     XX1FuncFini; unset XX1FuncFini; return 0
     ;;
  *) ##### If connection couldn't be established,...
     XX1DUMMY=$(db2 LIST APPLICATIONS | tr -s "\t" " " | tr -s " " ":" | rev | cut -d":" -f3,5 | rev | grep -i ":$XX1DB$" | cut -d":" -f1 | tr "\n" ",")
     XX1DUMMY=${XX1DUMMY%,}
     if [ ! -z "$XX1DUMMY" ]; then
      XX1STMT="FORCE APPLICATION ("$XX1DUMMY")"
      echo $XX1STMT; db2 $XX1STMT     
     fi
     ;;
 esac
done
#------------------------------------------------------------------------------





