/* ######################################################################### */
/* ##                                                                     ## */
/* ##  D B T U T O O L S / C O R E / O P T ... T R E E . J A V A          ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Job .......: Wrapper class, implementing the /opt/dbtutools tree   ## */
/* ##               related stuff.                                        ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Copyright (C) 2002  Daniel Scheibli                                ## */
/* ##                                                                     ## */
/* ##  This library is free software; you can redistribute it and/or      ## */
/* ##  modify it under the terms of the GNU Lesser General Public         ## */
/* ##  License as published by the Free Software Foundation; either       ## */
/* ##  version 2.1 of the License, or (at your option) any later version. ## */
/* ##                                                                     ## */
/* ##  This library is distributed in the hope that it will be useful,    ## */
/* ##  but WITHOUT ANY WARRANTY; without even the implied warranty of     ## */
/* ##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU  ## */
/* ##  Lesser General Public License for more details.                    ## */
/* ##                                                                     ## */
/* ##  You should have received a copy of the GNU Lesser General Public   ## */
/* ##  License along with this library; if not, write to the Free         ## */
/* ##  Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,     ## */
/* ##  MA 02111-1307 USA                                                  ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Remark ....: <none>                                                ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Author ....: Daniel Scheibli <daniel.scheibli@edelbyte.org>        ## */
/* ##  Date ......: 2002-10-20                                            ## */
/* ##  Changes ...: ----- OptDbtuToolsTree.java V00.99/R020 ------------- ## */
/* ##               <none>                                                ## */
/* ##               ----- OptDbtuToolsTree.java V00.99/R011 ------------- ## */
/* ##               <none>                                                ## */
/* ##                                                                     ## */
/* ######################################################################### */



/* ##### Presettings */
/* ------------------------------------------------------------------------- */
package org.dbtutools.DbtuTools.core;
/* ------------------------------------------------------------------------- */





/* ##### Class definition */
/** ************************************************************************
 * Wrapper class, implementing the /opt/dbtutools tree related stuff.
 * @author Daniel Scheibli &lt;daniel.scheibli at edelbyte.org&gt;
 * ************************************************************************* */
public class OptDbtuToolsTree
{
 /* ##### Presettings (instance fields)
 /* ------------------------------------------------------------------------ */
 /** ***********************************************************************
  * Field holding the machine wide /opt/dbtutools tree root.
  * ************************************************************************ */
 protected java.lang.String oTreeRoot; 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -- */
 /** ***********************************************************************
  * Field holding the given DB2 Instance name.
  * ************************************************************************ */
 protected java.lang.String oDb2Instance; 
 /* ------------------------------------------------------------------------ */





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   O P T D B T U T O O L S T R E E ()                               ## */
 /* ##                                                                    ## */
 /* ######################################################################## */
 /** ***********************************************************************
  * Creates a new instance of this class and addresses the
  * /opt/dbtutools tree for the current DB2 Instance.
  * 
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the name of the current
  *            DB2 Instance could not be detected.
  * ************************************************************************ */
 public OptDbtuToolsTree( ) throws org.edelbyte.util.UnknownValueException
 { this.detectTreeRoot( org.dbtutools.DbtuTools.core.db2.Instance.getInstance().getInstanceName() ); }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   O P T D B T U T O O L S T R E E ()                               ## */
 /* ##                                                                    ## */
 /* ######################################################################## */
 /** ***********************************************************************
  * Creates a new instance of this class and addresses the
  * /opt/dbtutools tree for the given DB2 Instance name.
  * 
  * @param oDb2InstanceName
  *        The name of the DB2 Instance to be addressed.
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the name of the current
  *            DB2 Instance could not be detected.
  * ************************************************************************ */
 public OptDbtuToolsTree( java.lang.String oDb2InstanceName ) throws org.edelbyte.util.UnknownValueException
 { this.detectTreeRoot( oDb2InstanceName ); }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   O P T D B T U T O O L S T R E E ()                               ## */
 /* ##                                                                    ## */
 /* ######################################################################## */
 /** ***********************************************************************
  * Creates a new instance of this class and addresses the
  * /opt/dbtutools tree for the given DB2 Instance.
  * 
  * @param oDb2InstanceName
  *        The DB2 Instance to be addressed.
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the name of the current
  *            DB2 Instance could not be detected.
  * ************************************************************************ */
 public OptDbtuToolsTree( org.dbtutools.DbtuTools.core.db2.Instance oDb2Instance ) throws org.edelbyte.util.UnknownValueException
 { this.detectTreeRoot( oDb2Instance.getInstanceName() ); }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   G E T I N S T A N C E ()                                         ## */
 /* ##                                                                    ## */ 
 /* ######################################################################## */
 /** ***********************************************************************
  * Creates and returns an instance of this class which
  * addresses the /opt/dbtutools tree for the current
  * DB2 Instance.
  *
  * @return The object addressing the /opt/dbtutools tree
  *         for the current DB2 Instance.
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the name of the current
  *            DB2 Instance could not be detected.
  * ************************************************************************ */ 
 public static org.dbtutools.DbtuTools.core.OptDbtuToolsTree getInstance( ) throws org.edelbyte.util.UnknownValueException
 { return( new org.dbtutools.DbtuTools.core.OptDbtuToolsTree() ); }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   G E T P A T H N A M E S ()                                       ## */
 /* ##                                                                    ## */ 
 /* ######################################################################## */
 /** ***********************************************************************
  * Returns the /opt/dbtutools tree path names (based on the
  * {@link #oTreeRoot} field).
  *
  * @return A new HashMap, containing the different paths.
  *         In the following you will find a list of the
  *         defined hash key:
  *         <ul>
  *          <li><code>&quot;Tree.Root&quot;</code> = Root path of the
  *              entire /opt/dbtutools tree (spanning all DB2 Instances).
  *          <li><code>&quot;Tree.Instance.Root&quot;</code> = Root
  *              path of the /opt/dbtutools tree (for the specified
  *              DB2 Instance).
  *          <li><code>&quot;Tree.Instance.Bin&quot;</code> = Path of
  *              the binary directory within the /opt/dbtutools tree.
  *          <li><code>&quot;Tree.Instance.Cfg&quot;</code> = Path
  *              holding the configuration files within the /opt/dbtutools
  *              tree.
  *          <li><code>&quot;Tree.Instance.Lib&quot;</code> = Path
  *              holding the libraries (JAR files etc) within the
  *              /opt/dbtutools tree (currently the same director
  *              as for the binaries)
  *          <li><code>&quot;Tree.Instance.Log&quot;</code> = Path
  *              holding the log files within the /opt/dbtutools tree.
  *          <li><code>&quot;Tree.Instance.Temp&quot;</code> = Path
  *              holding the temporary files within the /opt/dbtutools
  *              tree.
  *         </ul>
  * ************************************************************************ */ 
 public java.util.HashMap getPathNames( )
 {
  /* ##### Presettings */
  /* ----------------------------------------------------------------------- */
  java.util.HashMap oPaths = new java.util.HashMap(16); 
  /* ----------------------------------------------------------------------- */    



  /* ##### Assemble the hashmap */
  /* ----------------------------------------------------------------------- */
  oPaths.put( "Tree.Root",          this.oTreeRoot );
  oPaths.put( "Tree.Instance.Root", this.oTreeRoot + java.io.File.separator + this.oDb2Instance );
  oPaths.put( "Tree.Instance.Bin",  this.oTreeRoot + java.io.File.separator + this.oDb2Instance + java.io.File.separator + "tools" + java.io.File.separator + "bin"  );
  oPaths.put( "Tree.Instance.Cfg",  this.oTreeRoot + java.io.File.separator + this.oDb2Instance + java.io.File.separator + "tools" + java.io.File.separator + "cfg"  );
  oPaths.put( "Tree.Instance.Lib",  this.oTreeRoot + java.io.File.separator + this.oDb2Instance + java.io.File.separator + "tools" + java.io.File.separator + "bin"  );
  oPaths.put( "Tree.Instance.Log",  this.oTreeRoot + java.io.File.separator + this.oDb2Instance + java.io.File.separator + "tools" + java.io.File.separator + "log"  );
  oPaths.put( "Tree.Instance.Temp", this.oTreeRoot + java.io.File.separator + this.oDb2Instance + java.io.File.separator + "tools" + java.io.File.separator + "temp" );
  /* ----------------------------------------------------------------------- */


  
  /* ##### Return the PathNames */
  /* ----------------------------------------------------------------------- */
  return( oPaths );
  /* ----------------------------------------------------------------------- */  
 }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   D E T E C T T R E E R O O T ()                                   ## */
 /* ##                                                                    ## */
 /* ######################################################################## */
 /** ***********************************************************************
  * As the method name says, this method reads the
  * root path for the /opt/dbtutools tree and sets
  * the {@link #oTreeRoot} field.<br />
  * <br />
  * <i>Background:</i> The detection is done by interpreting the value of
  * <code>java.lang.System.getProperty(&quot;DBTUTOOLSHOME&quot;);</code>
  * and
  * <code>java.lang.System.getProperty(&quot;DB2INSTANCE&quot;);</code>
  * (for validation)
  *
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the environment variable
  *            <code>DBTUTOOLSHOME</code> or
  *            <code>DB2INSTANCE</code>wasn't set or contains
  *            no value (maybe, because of the fact that this
  *            environment variable was not passed to the java
  *            application).
  * ************************************************************************ */ 
 private void detectTreeRoot( java.lang.String oDb2InstanceName ) throws org.edelbyte.util.UnknownValueException
 {
  /* ##### Presettings */
  /* ----------------------------------------------------------------------- */
  java.lang.String          oDb2InstanceNameEnv         = java.lang.System.getProperty( "DB2INSTANCE" );
  java.lang.String          oInstanceTreeRoot           = java.lang.System.getProperty( "DBTUTOOLSHOME" );
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
  java.util.StringTokenizer oInstanceTreeRootTokens     = new java.util.StringTokenizer( oInstanceTreeRoot, java.io.File.separator, true );
  java.lang.String[]        oInstanceTreeRootTokenArray = null;
  java.lang.StringBuffer    oInstanceTreeRootNew        = new java.lang.StringBuffer();
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */  
  int                       iDummy, I;
  /* ----------------------------------------------------------------------- */   



  /* ##### Do a first check of the discovered values */
  /* ----------------------------------------------------------------------- */
  if( (oDb2InstanceNameEnv == null) ||
      (oDb2InstanceNameEnv.length() <= 0) )
  { throw new org.edelbyte.util.UnknownValueException( "Environment variable DB2INSTANCE was not set or contains no value." ); }
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
  if( (oInstanceTreeRoot == null) ||
      (oInstanceTreeRoot.length() <= 0) )
  { throw new org.edelbyte.util.UnknownValueException( "Environment variable DBTUTOOLSHOME was not set or contains no value." ); }
  /* ----------------------------------------------------------------------- */



  /* ##### Copy the TreeRoot tokens into an array */
  /* ----------------------------------------------------------------------- */
  oInstanceTreeRootTokenArray = new java.lang.String[oInstanceTreeRootTokens.countTokens()];
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
  for( I = 0; oInstanceTreeRootTokens.hasMoreTokens(); I++ )
  { oInstanceTreeRootTokenArray[I] = oInstanceTreeRootTokens.nextToken(); }
  /* ----------------------------------------------------------------------- */



  /* ##### Skip the last token (if it is the file seperator itself) */
  /* ----------------------------------------------------------------------- */
  iDummy = oInstanceTreeRootTokenArray.length - 1;
  if( oInstanceTreeRootTokenArray[iDummy].compareTo(java.io.File.separator) == 0 )
  { iDummy -= 1; }
  /* ----------------------------------------------------------------------- */



  /* ##### Check the last token of the TreeRoot */
  /* ##### (must be same as the DB2 Instance name) */
  /* ----------------------------------------------------------------------- */
  if( oInstanceTreeRootTokenArray[iDummy].compareToIgnoreCase(oDb2InstanceNameEnv) != 0 )
  { throw new org.edelbyte.util.UnknownValueException( "The last token of the environment variable DBTUTOOLSHOME must match DB2INSTANCE." ); }
  /* ----------------------------------------------------------------------- */



  /* ##### Assemble and set the new TreeRoot and DB2 Instance value */
  /* ----------------------------------------------------------------------- */
  for( I = 0; I < (iDummy - 1); I++ )     /* ##### (iDummy + 1) minus 2 to skip the DB2 Instance name */
  { oInstanceTreeRootNew.append( oInstanceTreeRootTokenArray[I] ); }
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */  
  this.oTreeRoot    = oInstanceTreeRootNew.toString();
  this.oDb2Instance = oDb2InstanceName;
  /* ----------------------------------------------------------------------- */
 }
}
/* ------------------------------------------------------------------------- */




