/* ######################################################################### */
/* ##                                                                     ## */
/* ##  D B T U T O O L S / C O R E / D B 2 / I N S T A N C E . J A V A    ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Job .......: Wrapper class, implementing DB2 Instance              ## */
/* ##               related stuff.                                        ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Copyright (C) 2002  Daniel Scheibli                                ## */
/* ##                                                                     ## */
/* ##  This library is free software; you can redistribute it and/or      ## */
/* ##  modify it under the terms of the GNU Lesser General Public         ## */
/* ##  License as published by the Free Software Foundation; either       ## */
/* ##  version 2.1 of the License, or (at your option) any later version. ## */
/* ##                                                                     ## */
/* ##  This library is distributed in the hope that it will be useful,    ## */
/* ##  but WITHOUT ANY WARRANTY; without even the implied warranty of     ## */
/* ##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU  ## */
/* ##  Lesser General Public License for more details.                    ## */
/* ##                                                                     ## */
/* ##  You should have received a copy of the GNU Lesser General Public   ## */
/* ##  License along with this library; if not, write to the Free         ## */
/* ##  Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,     ## */
/* ##  MA 02111-1307 USA                                                  ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Remark ....: <none>                                                ## */
/* ##                                                                     ## */
/* ## ------------------------------------------------------------------- ## */
/* ##                                                                     ## */
/* ##  Author ....: Daniel Scheibli <daniel.scheibli@edelbyte.org>        ## */
/* ##  Date ......: 2002-10-20                                            ## */
/* ##  Changes ...: ----- Instance.java V00.99/R020 --------------------- ## */
/* ##               <none>                                                ## */
/* ##               ----- Instance.java V00.99/R011 --------------------- ## */
/* ##               <none>                                                ## */
/* ##                                                                     ## */
/* ######################################################################### */



/* ##### Presettings */
/* ------------------------------------------------------------------------- */
package org.dbtutools.DbtuTools.core.db2;
/* ------------------------------------------------------------------------- */





/* ##### Class definition */
/** ************************************************************************
 * Wrapper class, implementing DB2 Instance related stuff.
 * @author Daniel Scheibli &lt;daniel.scheibli at edelbyte.org&gt;
 * ************************************************************************* */
public class Instance
{
 /* ##### Presettings (instance fields)
 /* ------------------------------------------------------------------------ */
 /** ***********************************************************************
  * Field holding the name of the DB2 instance, which is
  * addressed by the instance of this class.
  * ************************************************************************ */
 protected java.lang.String oInstanceName; 
 /* ------------------------------------------------------------------------ */

 
 
 
 
 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   I N S T A N C E ()                                               ## */
 /* ##                                                                    ## */ 
 /* ######################################################################## */
 /** ***********************************************************************
  * Creates a new instance of this class and addressed the
  * current DB2 Instance.<br />
  * <br />
  * <i>Background:</i> This constructor calls a private
  * method which interprets the value returned by
  * <code>java.lang.System.getProperty(&quot;DB2INSTANCE&quot;);</code>
  * 
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the name of the current
  *            DB2 Instance could not be detected.
  * ************************************************************************ */
 public Instance( ) throws org.edelbyte.util.UnknownValueException
 { this.setInstanceNameByEnvironment(); }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   I N S T A N C E ()                                               ## */
 /* ##                                                                    ## */ 
 /* ######################################################################## */
 /** ***********************************************************************
  * Creates a new instance of this class - addressing the provided
  * DB2 Instance name.<br />
  * <br />
  * <i>Remark:</i> Please notice, the constructor does not
  * check for the existence of the given DB2 instance!
  * 
  * @param oInstanceName
  *        The name of the DB2 Instance to be addressed.
  * @exception java.lang.NullPointerException
  *            If the <code>oInstanceName</code> argument was
  *            <code>null</null>.
  * ************************************************************************ */
 public Instance( java.lang.String oInstanceName ) throws java.lang.NullPointerException
 {
  /* ##### Check and process the given value */
  /* ----------------------------------------------------------------------- */  
  if( oInstanceName != null )
  { throw new java.lang.NullPointerException(); }
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
  this.oInstanceName = oInstanceName;
  /* ----------------------------------------------------------------------- */  
 }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   G E T I N S T A N C E ()                                         ## */
 /* ##                                                                    ## */ 
 /* ######################################################################## */
 /** ***********************************************************************
  * Creates and returns an instance of this class which
  * addresses the current DB2 Instance.
  *
  * @return The Instance object addressing the current
  *         DB2 Instance.
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the name of the current
  *            DB2 Instance could not be detected.
  * ************************************************************************ */ 
 public static org.dbtutools.DbtuTools.core.db2.Instance getInstance( ) throws org.edelbyte.util.UnknownValueException
 { return( new org.dbtutools.DbtuTools.core.db2.Instance() ); }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   G E T I N S T A N C E N A M E ()                                 ## */
 /* ##                                                                    ## */ 
 /* ######################################################################## */
 /** ***********************************************************************
  * Returns the DB2 Instance name (from the
  * {@link #oInstanceName} field).
  *
  * @return A new String, containing the DB2 Instance name.
  * ************************************************************************ */ 
 public java.lang.String getInstanceName( )
 { return( this.oInstanceName ); }





 /* ######################################################################## */
 /* ##                                                                    ## */
 /* ##   S E T I N S T A N C E N A M E B Y E N V I R O N M E N T ()       ## */
 /* ##                                                                    ## */ 
 /* ######################################################################## */
 /** ***********************************************************************
  * As the method name says, this method reads the name of
  * the DB2 Instance from the environment and sets the
  * {@link #oInstanceName} field.<br />
  * <br />
  * <i>Background:</i> The detection is done by interpreting the value of
  * <code>java.lang.System.getProperty(&quot;DB2INSTANCE&quot;);</code>
  *
  * @exception org.edelbyte.util.UnknownValueException
  *            For the case, that the environment variable
  *            <code>DB2INSTANCE</code> wasn't set or contains
  *            no value (maybe, because of the fact that this
  *            environment variable was not passed to the java
  *            application).<BR>
  * ************************************************************************ */ 
 private void setInstanceNameByEnvironment( ) throws org.edelbyte.util.UnknownValueException
 {
  /* ##### Presettings */
  /* ----------------------------------------------------------------------- */
  java.lang.String oInstanceName = java.lang.System.getProperty( "DB2INSTANCE" );
  /* ----------------------------------------------------------------------- */   



  /* ##### Check and process the value */
  /* ----------------------------------------------------------------------- */     
  if( (oInstanceName != null) &&
      (oInstanceName.length() > 0) )
  { this.oInstanceName = oInstanceName; }
  /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */  
  else      
  { throw new org.edelbyte.util.UnknownValueException( "Environment variable DB2INSTANCE was not set or contains no value." ); }
  /* ----------------------------------------------------------------------- */   
 }			    
}
/* ------------------------------------------------------------------------- */




